function data=run_lammps_MPC()
% Predefined stuff
    meam_lib = 'library.meam';
    meam_param = 'AlSiMgCuFe.meam';
    element_list = 'AlS SiS MgS CuS FeS';% elements in order from meam_lib that correspond to meam_param indices
    type = [1 3 5];%elements of interest from element_list
    lattice1={'FCC','HCP','BCC'};%primary lattices corresponding to elements
    lattice2={'BCC','FCC','FCC'};%secondary lattices
    lattice3={'HCP','BCC','HCP'};%secondary2 lattices
    alat=[4.05 3.194 2.851];%alat from lib file
    E0 = [3.353 1.51 4.28];%esub from lib file
    alpha = [4.64 5.52 5.027];%alpha from lib file
    BLattices = {'B1','B2','C1','C2','L12'};% Selected by user for calibration/validation, B1 is usually required.
    % whos('*')
    
    % Open lammps. Allocates memory for stuff. Only do this at the start of each
    % calibration routine, not for every lammps calculation.
    ptr = lammps_open('-screen','none');
    % to supprese console output:
    % ptr = lammps_open('-screen','none');
    % for custom log file:
    % ptr = lammps_open('-log','customlammpslog.out');
    
    % lammps_MPC uses flags to determine what to run. The single element
    % calculations are assigned flags as follows:
    % 1) Primary EV curve
    % 2) Secondary EV curve
    % 4) Secondary2 EV curve
    % 8) Elastic Constants Calculation
    % 16) Vacancy Energy Calculation
    % 32) Interstitital Energy Calculations
    % 64) Surface Energy Calculations
    % 128) Generalized Stacking Fault Energy Calculations
    % These flags are added together to get the total value for the terms
    % "SingleElementSetupflags" and "SingleElementRunflags", as
    % demonstrated below. Binary flags work the same way with the following
    % values:
    % 1) Binary EV Curves
    % 2) Binary Elastic Constants Calculation
    % 3) Substitution Energy
    % 4) Interstitial Substitution Energy
    % Ternary flags are only for the binding energy, so there is only the
    % values 0 and 1 for each set of elements. 
    %
    % 'SingleElementSetupflags' and 'SingleElementRunflags' must preceed
    % vectors of values corresponding to each element in types.
    % 'BinarySetupflags' and 'BinaryRunflags' should preceed matrices of
    % values corresponding to combinations of each element. Likewise,
    % 'TernarySetupflags' and 'TernaryRunflags' should preceed ntype x
    % ntype x ntype arrays of values for each element combination.
    % 
    % Other flags are available to fine-tune further what calculations are
    % performed: "...,'Interstitialflags',index,flag,..." means for
    % type(index), only perform the interstitial calculations corresponding
    % to flag with valid values from 0-31. Which calculations these are 
    % varies depending on the lattice. 1 means do the first interstitial
    % calculation, 2 the second, 4 the 3rd, 8 the 4th, and 16, the 5th. Not
    % all lattices have up to 5 intestitial calculations.
    % "...,'Surfaceflags',index,flag,..." works identically to
    % Interstitialflags, as does "...,'GSFEflags',index,flag,...".
    % 
    % "...,'BinaryLatticeEVflags',index1,index2,flag,..." defines a string
    % of comma-separated-values which mean for the alloy combination of
    % type(index1) and type(index2), compute the EV curve for
    % flag='B1,B2,C2,C15,etc'. Likewise, BinaryLatticeElasticflags defines
    % a string for the Elastic calculations.
    % 
    % These are all the flags needed to completely define what calculations
    % are run with each function call to lammps_MPC. The following should
    % be noted for dependency calculations: 1) All Single Element
    % calculations depend on the primary EV curve data. If you are not
    % running the primary EV curve, E0 and box must already be defined in
    % the data object sent to lammps_MPC. 2) All binary EV curves depend on
    % the EV curve data for their two elements. The single element curve
    % data for both of them must be defined. 3) All Binary calculations
    % depend on their corresponding EV calculation data. This means for the
    % binary elastic constants, you need to have the binary EV data for the
    % corresponding lattice defined. For the substitution and interstitial
    % substitution calculations, you need to have the single element EV
    % data for each element defined. 4) To run the binding energy
    % calculations you need a) the SingleElement EV data for all three
    % elements, and b) substitution data for element combinations 
    % (type1,type2) and (type1,type3).
    %
    % Further flag options allow refinement of how some of the calculations
    % are done. "...,'CustomEVrange',index,min,max,..." means for the
    % element type(index), use the values min and max for the minimum and
    % maximum ratio of the lattice parameter to compute the curve for.
    % Default values are 0.7 and 1.25.
    % "...,'CustomElasticConstants',index,Cs,..." means for the element
    % type(index), calculate the elastic constants
    % Cs='C11,C12,C44,C13,etc'. Default depends on the lattice, but is
    % usually 'C11,C12,C44'.
    % "...,'CustomBEVrange',index1,index2,min,max,..." is the same as
    % 'CustomEVrange, but for the binary EV curves.
    % "...,'CustomBElasticConstants',index1,index2,Cs,..." is the same as
    % 'CustomElasticConstants but for binaries.
    % "...,'CustomVacancySize',index,size,..." is the minimum cell length
    % in Angstroms for the vacancy calculation. Default: 10.
    % "...,'CustomInterstitialSize',index,size,..." is the minimum cell
    % length in Angstroms for the interstitial calculations. Default: 10.
    % "...,'CustomSurfaceDistance',index,dist,..." is the minimum distance
    % normal to the surface for surface calculations. Default: 10.
    % "...,'CustomGSFEDistance',index,dist,..." is the minimum distance
    % normal to the surface for GSFE calculations. Default: 10.
    
    
    
    
    try
        % Examples:
        display('Run rose cuve for all 3 elements')
        data=lammps_MPCv2(ptr,meam_lib,meam_param,element_list,type,lattice1,lattice2,lattice3, ...
            alat,E0,alpha,BLattices,[], ...
            'SingleElementSetupflags',[0 0 0], ...
            'SingleElementRunflags',[0 0 0], ...
            'BinaryRunflags',zeros(3,3), ...
            'TernaryRunflags',zeros(3,3,3), ...
            'BinarySetupflags',zeros(3,3), ...
            'TernarySetupflags',zeros(3,3,3));

if ~isempty(data)
    display('Return values are:')
    f1List = fieldnames(data);
    for i=1:length(f1List)
        if isstruct( data.(f1List{i}) )
            f2List = fieldnames(data.(f1List{i}));
            level3 = false;
%             for j=1:length(f2List)
%                 if isfield(data.(f1List{i}), f2List{j}) && isstruct( data.(f1List{i}).(f2List{j}) )
%                     f3List = fieldnames(data.(f1List{i}).(f2List{j}));
%                     display([' - ' f1List{i} '.' f2List{j} ':' sprintf(' %s ', f3List{:})])
%                     level3 = true;
%                 end
%             end
            if ~level3
                display([' - ' f1List{i} ':' sprintf(' %s ', f2List{:})])
            end
        end
    end
end
        
        display('basic command, no flags. Does everything.')
        data=lammps_MPCv2(ptr,meam_lib,meam_param,element_list,type,lattice1,lattice2,lattice3, ...
            alat,E0,alpha,BLattices,data);

if ~isempty(data)
    display('Return values are:')
    f1List = fieldnames(data);
    for i=1:length(f1List)
        if isstruct( data.(f1List{i}) )
            f2List = fieldnames(data.(f1List{i}));
            level3 = false;
%             for j=1:length(f2List)
%                 if isfield(data.(f1List{i}), f2List{j}) && isstruct( data.(f1List{i}).(f2List{j}) )
%                     f3List = fieldnames(data.(f1List{i}).(f2List{j}));
%                     display([' - ' f1List{i} '.' f2List{j} ':' sprintf(' %s ', f3List{:})])
%                     level3 = true;
%                 end
%             end
            if ~level3
                display([' - ' f1List{i} ':' sprintf(' %s ', f2List{:})])
            end
        end
    end
end
        
%         display('run only the primary EV curves for each element.')
%         data=lammps_MPCv2(ptr,meam_lib,meam_param,element_list,type,lattice1,lattice2,lattice3, ...
%             alat,E0,alpha,BLattices,data, ...
%             'SingleElementSetupflags',[0 0 0], ...
%             'SingleElementRunflags',[1 1 1], ...
%             'BinaryRunflags',[0 0 0;0 0 0;0 0 0], ...
%             'TernaryRunflags',zeros(3,3,3), ...
%             'BinarySetupflags',[0 0 0;0 0 0;0 0 0], ...
%             'TernarySetupflags',zeros(3,3,3));
% 
% if ~isempty(data)
%     display('Return values are:')
%     f1List = fieldnames(data);
%     for i=1:length(f1List)
%         if isstruct( data.(f1List{i}) )
%             f2List = fieldnames(data.(f1List{i}));
%             level3 = false;
%             for j=1:length(f2List)
%                 if isfield(data.(f1List{i}), f2List{j}) && isstruct( data.(f1List{i}).(f2List{j}) )
%                     f3List = fieldnames(data.(f1List{i}).(f2List{j}));
%                     display([' - ' f1List{i} '.' f2List{j} ':' sprintf(' %s ', f3List{:})])
%                     level3 = true;
%                 end
%             end
%             if ~level3
%                 display([' - ' f1List{i} ':' sprintf(' %s ', f2List{:})])
%             end
%         end
%     end
% end
%         
%         display('Setup all files only. Run nothing.')
%         data=lammps_MPCv2(ptr,meam_lib,meam_param,element_list,type,lattice1,lattice2,lattice3, ...
%             alat,E0,alpha,BLattices,data, ...
%             'SingleElementRunflags',[0 0 0], ...
%             'BinaryRunflags',[0 0 0;0 0 0;0 0 0], ...
%             'TernaryRunflags',zeros(3,3,3));
% 
% if ~isempty(data)
%     display('Return values are:')
%     f1List = fieldnames(data);
%     for i=1:length(f1List)
%         if isstruct( data.(f1List{i}) )
%             f2List = fieldnames(data.(f1List{i}));
%             level3 = false;
%             for j=1:length(f2List)
%                 if isfield(data.(f1List{i}), f2List{j}) && isstruct( data.(f1List{i}).(f2List{j}) )
%                     f3List = fieldnames(data.(f1List{i}).(f2List{j}));
%                     display([' - ' f1List{i} '.' f2List{j} ':' sprintf(' %s ', f3List{:})])
%                     level3 = true;
%                 end
%             end
%             if ~level3
%                 display([' - ' f1List{i} ':' sprintf(' %s ', f2List{:})])
%             end
%         end
%     end
% end
%         
%         display('Setup all files but run primary EV first to get best setup configuration.')
%         data=lammps_MPCv2(ptr,meam_lib,meam_param,element_list,type,lattice1,lattice2,lattice3, ...
%             alat,E0,alpha,BLattices,data, ...
%             'SingleElementRunflags',[1 1 1], ...
%             'BinaryRunflags',[0 1 1;1 0 1;1 1 0], ...
%             'TernaryRunflags',zeros(3,3,3));
%         
% if ~isempty(data)
%     display('Return values are:')
%     f1List = fieldnames(data);
%     for i=1:length(f1List)
%         if isstruct( data.(f1List{i}) )
%             f2List = fieldnames(data.(f1List{i}));
%             level3 = false;
%             for j=1:length(f2List)
%                 if isfield(data.(f1List{i}), f2List{j}) && isstruct( data.(f1List{i}).(f2List{j}) )
%                     f3List = fieldnames(data.(f1List{i}).(f2List{j}));
%                     display([' - ' f1List{i} '.' f2List{j} ':' sprintf(' %s ', f3List{:})])
%                     level3 = true;
%                 end
%             end
%             if ~level3
%                 display([' - ' f1List{i} ':' sprintf(' %s ', f2List{:})])
%             end
%         end
%     end
% end
% 
%         
%         display('Run all calculations only. Setup nothing.')
%         data=lammps_MPCv2(ptr,meam_lib,meam_param,element_list,type,lattice1,lattice2,lattice3, ...
%             alat,E0,alpha,BLattices,data, ...
%             'SingleElementSetupflags',[0 0 0], ...
%             'BinarySetupflags',[0 0 0;0 0 0;0 0 0], ...
%             'TernarySetupflags',zeros(3,3,3));
% 
% if ~isempty(data)
%     display('Return values are:')
%     f1List = fieldnames(data);
%     for i=1:length(f1List)
%         if isstruct( data.(f1List{i}) )
%             f2List = fieldnames(data.(f1List{i}));
%             level3 = false;
%             for j=1:length(f2List)
%                 if isfield(data.(f1List{i}), f2List{j}) && isstruct( data.(f1List{i}).(f2List{j}) )
%                     f3List = fieldnames(data.(f1List{i}).(f2List{j}));
%                     display([' - ' f1List{i} '.' f2List{j} ':' sprintf(' %s ', f3List{:})])
%                     level3 = true;
%                 end
%             end
%             if ~level3
%                 display([' - ' f1List{i} ':' sprintf(' %s ', f2List{:})])
%             end
%         end
%     end
% end
%         
%         display('Setup and Run single element EV curves, elastic constants, vacancy energy, and GSFE for Mg only, and Binary EV curves for Al-Mg.')
%         data=lammps_MPCv2(ptr,meam_lib,meam_param,element_list,type,lattice1,lattice2,lattice3, ...
%             alat,E0,alpha,BLattices,data, ...
%             'SingleElementSetupflags',[0 159 0], ...
%             'SingleElementRunflags',[0 159 0], ...
%             'BinaryRunflags',[0 1 0;1 0 0;0 0 0], ...
%             'TernaryRunflags',zeros(3,3,3), ...
%             'BinarySetupflags',[0 1 0;1 0 0;0 0 0], ...
%             'TernarySetupflags',zeros(3,3,3));    
% 
% if ~isempty(data)
%     display('Return values are:')
%     f1List = fieldnames(data);
%     for i=1:length(f1List)
%         if isstruct( data.(f1List{i}) )
%             f2List = fieldnames(data.(f1List{i}));
%             level3 = false;
%             for j=1:length(f2List)
%                 if isfield(data.(f1List{i}), f2List{j}) && isstruct( data.(f1List{i}).(f2List{j}) )
%                     f3List = fieldnames(data.(f1List{i}).(f2List{j}));
%                     display([' - ' f1List{i} '.' f2List{j} ':' sprintf(' %s ', f3List{:})])
%                     level3 = true;
%                 end
%             end
%             if ~level3
%                 display([' - ' f1List{i} ':' sprintf(' %s ', f2List{:})])
%             end
%         end
%     end
% end
        
        display('Close lammps only when calibration routine is finished. Saves a lot of time on memory allocation/deallocation.')
        lammps_close(ptr);
    catch err
        lammps_close(ptr);
        rethrow(err);
    end